==> waldur_api_client-0.1.0-py3-none-any.whl: waldur_api_client/models/service_provider_api_secret_code.py <==
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="ServiceProviderApiSecretCode")


@_attrs_define
class ServiceProviderApiSecretCode:
    """
    Attributes:
        api_secret_code (str):
    """

    api_secret_code: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        api_secret_code = self.api_secret_code

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "api_secret_code": api_secret_code,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        api_secret_code = d.pop("api_secret_code")

        service_provider_api_secret_code = cls(
            api_secret_code=api_secret_code,
        )

        service_provider_api_secret_code.additional_properties = d
        return service_provider_api_secret_code

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> waldur_api_client-7.7.0-py3-none-any.whl: waldur_api_client/models/service_provider_api_secret_code.py <==
from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="ServiceProviderApiSecretCode")


@_attrs_define
class ServiceProviderApiSecretCode:
    """
    Attributes:
        api_secret_code (str):
    """

    api_secret_code: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        api_secret_code = self.api_secret_code

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "api_secret_code": api_secret_code,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        api_secret_code = d.pop("api_secret_code")

        service_provider_api_secret_code = cls(
            api_secret_code=api_secret_code,
        )

        service_provider_api_secret_code.additional_properties = d
        return service_provider_api_secret_code

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
